//-------------------------------------------------------------------------------------
//
// Copyright 2009 Intel Corporation
// All Rights Reserved
//
// Permission is granted to use, copy, distribute and prepare derivative works of this
// software for any purpose and without fee, provided, that the above copyright notice
// and this statement appear in all copies.  Intel makes no representations about the
// suitability of this software for any purpose.  THIS SOFTWARE IS PROVIDED "AS IS."
// INTEL SPECIFICALLY DISCLAIMS ALL WARRANTIES, EXPRESS OR IMPLIED, AND ALL LIABILITY,
// INCLUDING CONSEQUENTIAL AND OTHER INDIRECT DAMAGES, FOR THE USE OF THIS SOFTWARE,
// INCLUDING LIABILITY FOR INFRINGEMENT OF ANY PROPRIETARY RIGHTS, AND INCLUDING THE
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  Intel does not
// assume any responsibility for any errors which may appear in this software nor any
// responsibility to update it.
//
#include "StdAfx.h"
#include "Misc/Defines.h"
#include "Gfx/GfxMath.h"
#include "Sono.h"

//
//	Theme by Steve Hughes, used with permission
//

 // Format      : 1
 // Tracks      : 8
 // TimeDivision: 192

static const sTrackItem Track00[] =
{
 //      0 Sequence/Track Name "Export1"
 //      0 Tempo = 500000 
 //      0 Key Signature 
 //      0 Time Signature 
 //      0 End of Track 
	{0xFFFF,0xFF,0xFF}
};

static const sTrackItem Track01[] =
{
 //      0 ??? 
 //      0 Sequence/Track Name "NN-XT 1"
 //      0  0 Main Volume=127
 //      0  0 Pan=64
 //      0  0 Program Change 24. GM: Tango Accordion
	{  5952, 64, 110}, 
	{    46, 64, 0}, 
	{     2, 65, 110}, 
	{    46, 65, 0}, 
	{     2, 64, 110}, 
	{    46, 64, 0}, 
	{     2, 65, 110}, 
	{    46, 65, 0}, 
	{     2, 67, 110}, 
	{  1296, 67, 0}, 
	{    48, 65, 110}, 
	{    46, 65, 0}, 
	{     2, 64, 110}, 
	{    46, 64, 0}, 
	{     2, 65, 110}, 
	{    46, 65, 0}, 
	{     2, 64, 110}, 
	{    46, 64, 0}, 
	{     2, 62, 110}, 
	{   256, 62, 0}, 
	{    32, 69, 110}, 
	{  1008, 69, 0}, 
	{    48, 64, 110}, 
	{    46, 64, 0}, 
	{     2, 65, 110}, 
	{    46, 65, 0}, 
	{     2, 64, 110}, 
	{    46, 64, 0}, 
	{     2, 65, 110}, 
	{    46, 65, 0}, 
	{     2, 67, 110}, 
	{  1296, 67, 0}, 
	{    48, 65, 110}, 
	{    46, 65, 0}, 
	{     2, 64, 110}, 
	{    46, 64, 0}, 
	{     2, 65, 110}, 
	{    46, 65, 0}, 
	{     2, 64, 110}, 
	{    46, 64, 0}, 
	{     2, 62, 110}, 
	{  1296, 62, 0}, 
 //      0 End of Track 
	{0xFFFF,0xFF,0xFF}
};

static const sTrackItem Track02[] =
{
 //      0 ??? 
 //      0 Sequence/Track Name "NN-XT 2"
 //      0  1 Main Volume=127
 //      0  1 Pan=64
 //      0  1 Program Change 85. GM: Lead 5 (charang)
	{ 12288, 77, 110}, 
	{    46, 77, 0}, 
	{     2, 76, 110}, 
	{    46, 76, 0}, 
	{     2, 77, 110}, 
	{   432, 77, 0}, 
	{    48, 79, 110}, 
	{    94, 79, 0}, 
	{     2, 77, 110}, 
	{   256, 77, 0}, 
	{    32, 79, 110}, 
	{    94, 79, 0}, 
	{     2, 77, 110}, 
	{   256, 77, 0}, 
	{    32, 79, 110}, 
	{    94, 79, 0}, 
	{     2, 77, 110}, 
	{   190, 77, 0}, 
	{     2, 74, 110}, 
	{  1392, 74, 0}, 
	{    48, 77, 110}, 
	{    46, 77, 0}, 
	{     2, 76, 110}, 
	{    46, 76, 0}, 
	{     2, 77, 110}, 
	{   432, 77, 0}, 
	{    48, 79, 110}, 
	{    94, 79, 0}, 
	{     2, 77, 110}, 
	{   256, 77, 0}, 
	{    32, 79, 110}, 
	{    94, 79, 0}, 
	{     2, 77, 110}, 
	{   256, 77, 0}, 
	{    32, 79, 110}, 
	{    94, 79, 0}, 
	{     2, 81, 110}, 
	{  1584, 81, 0}, 
 //      0 End of Track 
	{0xFFFF,0xFF,0xFF}
};

static const sTrackItem Track03[] =
{
 //      0 ??? 
 //      0 Sequence/Track Name "NN-XT 3"
 //      0  2 Main Volume=127
 //      0  2 Pan=64
 //      0  2 Program Change 87. GM: Lead 7 (fifths)
	{ 18240, 55, 110}, 
	{    94, 55, 0}, 
	{     2, 62, 127}, 
	{   256, 62, 0}, 
	{  1184, 55, 110}, 
	{    94, 55, 0}, 
	{     2, 62, 127}, 
	{   256, 62, 0}, 
	{  1184, 55, 110}, 
	{    94, 55, 0}, 
	{     2, 62, 110}, 
	{   256, 62, 0}, 
	{  1184, 55, 110}, 
	{    94, 55, 0}, 
	{     2, 62, 110}, 
	{   256, 62, 0}, 
 //      0 End of Track 
	{0xFFFF,0xFF,0xFF}
};

static const sTrackItem Track04[] =
{
 //      0 ??? 
 //      0 Sequence/Track Name "NN-XT 6"
 //      0  4 Main Volume=127
 //      0  4 Pan=64
 //      0  4 Program Change 36. GM: Fretless Bass
	{     0, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 53, 110}, 
	{    46, 53, 0}, 
	{     2, 53, 110}, 
	{    46, 53, 0}, 
	{     2, 53, 110}, 
	{    46, 53, 0}, 
	{     2, 53, 110}, 
	{    46, 53, 0}, 
	{     2, 53, 110}, 
	{    46, 53, 0}, 
	{     2, 53, 110}, 
	{    46, 53, 0}, 
	{     2, 53, 110}, 
	{    46, 53, 0}, 
	{     2, 53, 110}, 
	{    46, 53, 0}, 
	{     2, 48, 110}, 
	{    46, 48, 0}, 
	{     2, 48, 110}, 
	{    46, 48, 0}, 
	{     2, 48, 110}, 
	{    46, 48, 0}, 
	{     2, 48, 110}, 
	{    46, 48, 0}, 
	{     2, 48, 110}, 
	{    46, 48, 0}, 
	{     2, 48, 110}, 
	{    46, 48, 0}, 
	{     2, 48, 110}, 
	{    46, 48, 0}, 
	{     2, 48, 110}, 
	{    46, 48, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 53, 110}, 
	{    46, 53, 0}, 
	{     2, 53, 110}, 
	{    46, 53, 0}, 
	{     2, 53, 110}, 
	{    46, 53, 0}, 
	{     2, 53, 110}, 
	{    46, 53, 0}, 
	{     2, 53, 110}, 
	{    46, 53, 0}, 
	{     2, 53, 110}, 
	{    46, 53, 0}, 
	{     2, 53, 110}, 
	{    46, 53, 0}, 
	{     2, 53, 110}, 
	{    46, 53, 0}, 
	{     2, 48, 110}, 
	{    46, 48, 0}, 
	{     2, 48, 110}, 
	{    46, 48, 0}, 
	{     2, 48, 110}, 
	{    46, 48, 0}, 
	{     2, 48, 110}, 
	{    46, 48, 0}, 
	{     2, 48, 110}, 
	{    46, 48, 0}, 
	{     2, 48, 110}, 
	{    46, 48, 0}, 
	{     2, 48, 110}, 
	{    46, 48, 0}, 
	{     2, 48, 110}, 
	{    46, 48, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
	{     2, 50, 110}, 
	{    46, 50, 0}, 
 //      0 End of Track 
	{0xFFFF,0xFF,0xFF}
};

static const sTrackItem Track05[] =
{
 //      0 ??? 
 //      0 Sequence/Track Name "NN-XT 5"
 //      0  5 Main Volume=127
 //      0  5 Pan=64
 //      0  5 Program Change 49. GM: String Ensemble 1
	{     0, 62, 45}, 
	{     0, 67, 45}, 
	{     0, 70, 45}, 
	{     0, 74, 45}, 
	{     0, 79, 45}, 
	{   720, 79, 0}, 
	{    48, 77, 45}, 
	{   720, 62, 0}, 
	{     0, 67, 0}, 
	{     0, 70, 0}, 
	{     0, 74, 0}, 
	{     0, 77, 0}, 
	{    48, 62, 45}, 
	{     0, 65, 45}, 
	{     0, 69, 45}, 
	{     0, 74, 45}, 
	{   768, 77, 45}, 
	{   720, 62, 0}, 
	{     0, 65, 0}, 
	{     0, 69, 0}, 
	{     0, 74, 0}, 
	{     0, 77, 0}, 
	{    48, 62, 45}, 
	{     0, 67, 45}, 
	{     0, 70, 45}, 
	{     0, 74, 45}, 
	{     0, 79, 45}, 
	{  1488, 62, 0}, 
	{     0, 67, 0}, 
	{     0, 70, 0}, 
	{     0, 74, 0}, 
	{     0, 79, 0}, 
	{    48, 62, 45}, 
	{     0, 65, 45}, 
	{     0, 69, 45}, 
	{     0, 74, 45}, 
	{     0, 81, 45}, 
	{  1488, 62, 0}, 
	{     0, 65, 0}, 
	{     0, 69, 0}, 
	{     0, 74, 0}, 
	{     0, 81, 0}, 
 //     48  5 Program Change 48. GM: Timpani
	{    48, 62, 45}, 
	{     0, 67, 45}, 
	{     0, 70, 45}, 
	{     0, 74, 45}, 
	{  1488, 62, 0}, 
	{     0, 67, 0}, 
	{     0, 70, 0}, 
	{     0, 74, 0}, 
	{    48, 62, 45}, 
	{     0, 65, 45}, 
	{     0, 69, 45}, 
	{     0, 74, 45}, 
	{  1488, 62, 0}, 
	{     0, 65, 0}, 
	{     0, 69, 0}, 
	{     0, 74, 0}, 
	{    48, 62, 45}, 
	{     0, 67, 45}, 
	{     0, 70, 45}, 
	{     0, 74, 45}, 
	{  1488, 62, 0}, 
	{     0, 67, 0}, 
	{     0, 70, 0}, 
	{     0, 74, 0}, 
	{    48, 62, 45}, 
	{     0, 65, 45}, 
	{     0, 69, 45}, 
	{     0, 74, 45}, 
	{  1488, 62, 0}, 
	{     0, 65, 0}, 
	{     0, 69, 0}, 
	{     0, 74, 0}, 
	{    48, 62, 45}, 
	{     0, 65, 45}, 
	{     0, 69, 45}, 
	{     0, 74, 45}, 
	{   720, 62, 0}, 
	{     0, 65, 0}, 
	{     0, 69, 0}, 
	{     0, 74, 0}, 
	{    48, 65, 45}, 
	{     0, 69, 45}, 
	{     0, 72, 45}, 
	{     0, 77, 45}, 
	{   336, 65, 0}, 
	{     0, 69, 0}, 
	{     0, 72, 0}, 
	{     0, 77, 0}, 
	{    48, 64, 45}, 
	{     0, 69, 45}, 
	{     0, 72, 45}, 
	{     0, 76, 45}, 
	{   336, 64, 0}, 
	{     0, 69, 0}, 
	{     0, 72, 0}, 
	{     0, 76, 0}, 
	{    48, 62, 45}, 
	{     0, 65, 45}, 
	{     0, 69, 45}, 
	{     0, 74, 45}, 
	{   720, 62, 0}, 
	{     0, 65, 0}, 
	{     0, 69, 0}, 
	{     0, 74, 0}, 
	{    48, 62, 45}, 
	{     0, 65, 45}, 
	{     0, 69, 45}, 
	{     0, 74, 45}, 
	{   720, 62, 0}, 
	{     0, 65, 0}, 
	{     0, 69, 0}, 
	{     0, 74, 0}, 
	{    48, 62, 45}, 
	{     0, 65, 45}, 
	{     0, 69, 45}, 
	{     0, 74, 45}, 
	{   720, 62, 0}, 
	{     0, 65, 0}, 
	{     0, 69, 0}, 
	{     0, 74, 0}, 
	{    48, 65, 45}, 
	{     0, 69, 45}, 
	{     0, 72, 45}, 
	{     0, 77, 45}, 
	{   336, 65, 0}, 
	{     0, 69, 0}, 
	{     0, 72, 0}, 
	{     0, 77, 0}, 
	{    48, 64, 45}, 
	{     0, 69, 45}, 
	{     0, 72, 45}, 
	{     0, 76, 45}, 
	{   336, 64, 0}, 
	{     0, 69, 0}, 
	{     0, 72, 0}, 
	{     0, 76, 0}, 
	{    48, 62, 45}, 
	{     0, 65, 45}, 
	{     0, 69, 45}, 
	{     0, 74, 45}, 
	{   720, 62, 0}, 
	{     0, 65, 0}, 
	{     0, 69, 0}, 
	{     0, 74, 0}, 
	{    48, 62, 45}, 
	{     0, 65, 45}, 
	{     0, 69, 45}, 
	{     0, 74, 45}, 
	{   720, 62, 0}, 
	{     0, 65, 0}, 
	{     0, 69, 0}, 
	{     0, 74, 0}, 
	{    48, 62, 45}, 
	{     0, 67, 45}, 
	{     0, 70, 45}, 
	{     0, 74, 45}, 
	{  1488, 62, 0}, 
	{     0, 67, 0}, 
	{     0, 70, 0}, 
	{     0, 74, 0}, 
	{    48, 62, 45}, 
	{     0, 65, 45}, 
	{     0, 69, 45}, 
	{     0, 74, 45}, 
	{  1488, 62, 0}, 
	{     0, 65, 0}, 
	{     0, 69, 0}, 
	{     0, 74, 0}, 
	{    48, 62, 45}, 
	{     0, 67, 45}, 
	{     0, 70, 45}, 
	{     0, 74, 45}, 
	{  1488, 62, 0}, 
	{     0, 67, 0}, 
	{     0, 70, 0}, 
	{     0, 74, 0}, 
	{    48, 62, 45}, 
	{     0, 65, 45}, 
	{     0, 69, 45}, 
	{     0, 74, 45}, 
	{  1488, 62, 0}, 
	{     0, 65, 0}, 
	{     0, 69, 0}, 
	{     0, 74, 0}, 
 //      0 End of Track 
	{0xFFFF,0xFF,0xFF}
};

static const sTrackItem Track06[] =
{
 //      0 ??? 
 //      0 Sequence/Track Name "Staff-1"
 //      0  6 Main Volume=127
 //      0  6 Pan=64
 //      0  6 Program Change 118. GM: Melodic Tom
	{  3072, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
	{    32, 43, 45}, 
	{   160, 43, 0}, 
 //      0 End of Track 
	{0xFFFF,0xFF,0xFF}
};

static const sTrackItem Track07[] =
{
 //      0 ??? 
 //      0 Sequence/Track Name "Staff-2"
 //      0  9 Main Volume=127
 //      0  9 Pan=64
 //      0  9 Effects 1 Depth (formerly External Effects Depth)=64
	{  3072, 36, 110}, 
	{   160, 36, 0}, 
	{    32, 36, 110}, 
	{   160, 36, 0}, 
	{    32, 36, 110}, 
	{   160, 36, 0}, 
	{    32, 36, 110}, 
	{   160, 36, 0}, 
	{    32, 36, 110}, 
	{   160, 36, 0}, 
	{    32, 36, 110}, 
	{   160, 36, 0}, 
	{    32, 36, 110}, 
	{   160, 36, 0}, 
	{    32, 36, 110}, 
	{   160, 36, 0}, 
	{    32, 36, 110}, 
	{   160, 36, 0}, 
	{    32, 36, 110}, 
	{   160, 36, 0}, 
	{    32, 36, 110}, 
	{   160, 36, 0}, 
	{    32, 36, 110}, 
	{   160, 36, 0}, 
	{    32, 36, 110}, 
	{   160, 36, 0}, 
	{    32, 36, 110}, 
	{   160, 36, 0}, 
	{    32, 36, 110}, 
	{   160, 36, 0}, 
	{    32, 36, 110}, 
	{     0, 38, 110}, 
	{    46, 36, 0}, 
	{     0, 38, 0}, 
	{     2, 38, 110}, 
	{    46, 38, 0}, 
	{     2, 38, 110}, 
	{    46, 38, 0}, 
	{     2, 38, 110}, 
	{    46, 38, 0}, 
	{     2, 36, 110}, 
	{     0, 44, 110}, 
	{    94, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 38, 110}, 
	{     0, 44, 110}, 
	{    94, 38, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 36, 110}, 
	{     0, 44, 110}, 
	{    94, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 38, 110}, 
	{     0, 44, 110}, 
	{    94, 38, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 36, 110}, 
	{     0, 44, 110}, 
	{    94, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 38, 110}, 
	{     0, 44, 110}, 
	{    94, 38, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 36, 110}, 
	{     0, 44, 110}, 
	{    94, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 38, 110}, 
	{     0, 44, 110}, 
	{    94, 38, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 36, 110}, 
	{     0, 44, 110}, 
	{    94, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 38, 110}, 
	{     0, 44, 110}, 
	{    94, 38, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 36, 110}, 
	{     0, 44, 110}, 
	{    94, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 38, 110}, 
	{     0, 44, 110}, 
	{    94, 38, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 36, 110}, 
	{     0, 44, 110}, 
	{    94, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 38, 110}, 
	{     0, 44, 110}, 
	{    94, 38, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 36, 110}, 
	{     0, 44, 110}, 
	{    94, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 38, 110}, 
	{     0, 44, 110}, 
	{    94, 38, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 36, 110}, 
	{     0, 44, 110}, 
	{    94, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 38, 110}, 
	{     0, 44, 110}, 
	{    94, 38, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 36, 110}, 
	{     0, 44, 110}, 
	{    94, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 38, 110}, 
	{     0, 44, 110}, 
	{    94, 38, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 36, 110}, 
	{     0, 44, 110}, 
	{    94, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 38, 110}, 
	{     0, 44, 110}, 
	{    94, 38, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 36, 110}, 
	{     0, 44, 110}, 
	{    94, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 38, 110}, 
	{     0, 44, 110}, 
	{    94, 38, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 36, 110}, 
	{     0, 44, 110}, 
	{    94, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 38, 110}, 
	{     0, 44, 110}, 
	{    94, 38, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 36, 110}, 
	{     0, 44, 110}, 
	{    94, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 38, 110}, 
	{     0, 44, 110}, 
	{    94, 38, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 36, 110}, 
	{     0, 44, 110}, 
	{    94, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 38, 110}, 
	{     0, 44, 110}, 
	{    94, 38, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 36, 110}, 
	{     0, 44, 110}, 
	{    94, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    94, 44, 0}, 
	{     2, 38, 110}, 
	{     0, 40, 110}, 
	{    46, 38, 0}, 
	{     0, 40, 0}, 
	{     2, 40, 110}, 
	{    46, 40, 0}, 
	{     2, 40, 110}, 
	{    46, 40, 0}, 
	{     2, 40, 110}, 
	{    46, 40, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 40, 127}, 
	{     0, 44, 127}, 
	{    46, 40, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 40, 127}, 
	{     0, 44, 127}, 
	{    46, 40, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 40, 127}, 
	{     0, 44, 127}, 
	{    46, 40, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 40, 127}, 
	{     0, 44, 127}, 
	{    46, 40, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 40, 127}, 
	{     0, 44, 127}, 
	{    46, 40, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 40, 127}, 
	{     0, 44, 127}, 
	{    46, 40, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 40, 127}, 
	{     0, 44, 127}, 
	{    46, 40, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 38, 127}, 
	{     0, 40, 127}, 
	{    46, 38, 0}, 
	{     0, 40, 0}, 
	{     2, 40, 110}, 
	{    46, 40, 0}, 
	{     2, 40, 110}, 
	{    46, 40, 0}, 
	{     2, 40, 110}, 
	{    46, 40, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 40, 127}, 
	{     0, 44, 127}, 
	{    46, 40, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 40, 127}, 
	{     0, 44, 127}, 
	{    46, 40, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 40, 127}, 
	{     0, 44, 127}, 
	{    46, 40, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 40, 127}, 
	{     0, 44, 127}, 
	{    46, 40, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 40, 127}, 
	{     0, 44, 127}, 
	{    46, 40, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 40, 127}, 
	{     0, 44, 127}, 
	{    46, 40, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 40, 127}, 
	{     0, 44, 127}, 
	{    46, 40, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 40, 127}, 
	{     0, 44, 127}, 
	{    46, 40, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 38, 127}, 
	{     0, 44, 127}, 
	{    46, 38, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 40, 127}, 
	{     0, 44, 127}, 
	{    46, 40, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 38, 127}, 
	{     0, 44, 127}, 
	{    46, 38, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 36, 127}, 
	{     0, 44, 127}, 
	{    46, 36, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 38, 127}, 
	{     0, 44, 127}, 
	{    46, 38, 0}, 
	{     0, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
	{     2, 44, 127}, 
	{    46, 44, 0}, 
	{     2, 44, 110}, 
	{    46, 44, 0}, 
 //      0 End of Track 
	{0xFFFF,0xFF,0xFF}
};

bool SetupNulsteinSong(CSono *pSono)
{
	pSono->SetTempo(500000, 192); /* s/quarter-note, ticks per beat */ 

	pSono->m_Channel[0].SetTrack(pSono, Track01 ); pSono->m_Channel[0].SetInstrument(pSono, 6);		/* 24. GM: Tango Accordion		*/ 
	pSono->m_Channel[1].SetTrack(pSono, Track02 ); pSono->m_Channel[1].SetInstrument(pSono, 17);		/* 85. GM: Lead 5 (charang)		*/ 
	// pSono->m_Channel[2].SetTrack(pSono, Track03 ); pSono->m_Channel[2].SetInstrument(pSono, 87);		/* 87. GM: Lead 7 (fifths)		*/ 
	pSono->m_Channel[3].SetTrack(pSono, Track04 ); pSono->m_Channel[3].SetInstrument(pSono, 33);		/* 36. GM: Fretless Bass		*/ 
	pSono->m_Channel[4].SetTrack(pSono, Track05 ); pSono->m_Channel[4].SetInstrument(pSono, 52);		/* 49. GM: String Ensemble 1	*/ 
	pSono->m_Channel[5].SetTrack(pSono, Track06 ); pSono->m_Channel[5].SetInstrument(pSono, 118);		/* 118. GM: Melodic Tom			*/ 
	pSono->m_Channel[6].SetTrack(pSono, Track07 ); pSono->m_Channel[6].m_bDrums = true;
	
	pSono->SetLoop(12288); 
	
	return true;	
}